@@ -50,7 +50,7 @@ class ActionManager(models.Manager):
         Produces a QuerySet of most recent activities for any model
         """
         return self.filter(
-            actor_content_type = ContentType.objects.get_for_model(model),
+            target_content_type = ContentType.objects.get_for_model(model)
         ).order_by('-timestamp')
         
 class Action(models.Model):
@@ -127,11 +127,12 @@ class Action(models.Model):
         return ('actstream.views.detail', [self.pk])
         
 
-def follow(user, actor):
+def follow(user, actor, send_action=True):
     """
     Creates a ``User`` -> ``Actor`` follow relationship such that the actor's activities appear in the user's stream.
     Also sends the ``<user> started following <actor>`` action signal.
-    Returns the created ``Follow`` instance
+    Returns the created ``Follow`` instance.
+    If ``send_action`` is false, no "started following" signal will be created
     
     Syntax::
     
@@ -142,7 +143,8 @@ def follow(user, actor):
         follow(request.user, group)
     
     """
-    action.send(user, verb=_('started following'), target=actor)
+    if send_action:
+        action.send(user, verb=_('started following'), target=actor)
     return Follow.objects.create(user = user, object_id = actor.pk, 
         content_type = ContentType.objects.get_for_model(actor))
     
@@ -181,16 +183,14 @@ model_stream.__doc__ = Action.objects.stream_for_model.__doc__
 def action_handler(verb, target=None, public=True, **kwargs):
     actor = kwargs.pop('sender')
     kwargs.pop('signal', None)
-    kw = {
-        'actor_content_type': ContentType.objects.get_for_model(actor),
-        'actor_object_id': actor.pk,
-        'verb': unicode(verb),
-        'public': bool(public),
-    }
+    action = Action(actor_content_type=ContentType.objects.get_for_model(actor),
+                    actor_object_id=actor.pk,
+                    verb=unicode(verb),
+                    public=bool(public))
     if target:
-        kw.update(target_object_id=target.pk,
-            target_content_type=ContentType.objects.get_for_model(target))
-    kw.update(kwargs)
-    Action.objects.get_or_create(**kw)[0]
+        action.target_object_id=target.pk
+        action.target_content_type=ContentType.objects.get_for_model(target)
+
+    action.save()
     
-action.connect(action_handler)
+action.connect(action_handler, dispatch_uid="actstream.models")
