@@ -100,4 +100,10 @@ class ActivityTestCase(unittest.TestCase):
         for i,m in enumerate((Comment,ContentType,Player,Follow,Action,User,Group)):
             f = open('testdata%d.json'%i,'w')
             f.write(serialize('json',m.objects.all()))
-            f.close()
\ No newline at end of file
+            f.close()
+        Action.objects.all().delete()
+        Comment.objects.all().delete()
+        Player.objects.all().delete()
+        User.objects.all().delete()
+        Group.objects.all().delete()
+        Follow.objects.all().delete()
